@@ -19,6 +19,9 @@ static marpaWrapperValueOption_t marpaWrapperValueOptionDefault = {
   0                               /* maxParsesi */
 };
 
+/* Macro that return genericLoggerp from a marpaWrapperValuep */
+#define GENERICLOGGERP(marpaWrapperValuep) ((marpaWrapperValuep != NULL) ? (marpaWrapperValuep)->marpaWrapperValueOption.genericLoggerp : NULL)
+
 /****************************************************************************/
 marpaWrapperValue_t *marpaWrapperValue_newp(marpaWrapperRecognizer_t *marpaWrapperRecognizerp, marpaWrapperValueOption_t *marpaWrapperValueOptionp)
 /****************************************************************************/
@@ -31,10 +34,12 @@ marpaWrapperValue_t *marpaWrapperValue_newp(marpaWrapperRecognizer_t *marpaWrapp
   int                   ambiguousi;
   int                   nulli;
 
-  if (marpaWrapperRecognizerp == NULL) {
+#ifndef NDEBUG
+  if (MARPAWRAPPER_UNLIKELY(marpaWrapperRecognizerp == NULL)) {
     errno = EINVAL;
     goto err;
   }
+#endif
 
   if (marpaWrapperValueOptionp == NULL) {
     marpaWrapperValueOptionp = &marpaWrapperValueOptionDefault;
@@ -42,14 +47,14 @@ marpaWrapperValue_t *marpaWrapperValue_newp(marpaWrapperRecognizer_t *marpaWrapp
   genericLoggerp = marpaWrapperValueOptionp->genericLoggerp;
 
   /* Impossible if we are already valuating it */
-  if (marpaWrapperRecognizerp->treeModeb != MARPAWRAPPERRECOGNIZERTREEMODE_NA) {
+  if (MARPAWRAPPER_UNLIKELY(marpaWrapperRecognizerp->treeModeb != MARPAWRAPPERRECOGNIZERTREEMODE_NA)) {
     MARPAWRAPPER_ERROR(genericLoggerp, "Already in valuation mode");
     goto err;
   }
 
   /* Create a value instance */
-  marpaWrapperValuep = malloc(sizeof(marpaWrapperValue_t));
-  if (marpaWrapperValuep == NULL) {
+  marpaWrapperValuep = (marpaWrapperValue_t *) malloc(sizeof(marpaWrapperValue_t));
+  if (MARPAWRAPPER_UNLIKELY(marpaWrapperValuep == NULL)) {
     MARPAWRAPPER_ERRORF(genericLoggerp, "malloc failure: %s", strerror(errno));
     goto err;
   }
@@ -68,28 +73,28 @@ marpaWrapperValue_t *marpaWrapperValue_newp(marpaWrapperRecognizer_t *marpaWrapp
 
   MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_b_new(%p, %d)", marpaWrapperRecognizerp->marpaRecognizerp, (int) marpaLatestEarleySetIdi);
   marpaWrapperValuep->marpaBocagep = marpa_b_new(marpaWrapperRecognizerp->marpaRecognizerp, marpaLatestEarleySetIdi);
-  if (marpaWrapperValuep->marpaBocagep == NULL) {
+  if (MARPAWRAPPER_UNLIKELY(marpaWrapperValuep->marpaBocagep == NULL)) {
     MARPAWRAPPER_MARPA_G_ERROR(genericLoggerp, marpaWrapperRecognizerp->marpaWrapperGrammarp->marpaGrammarp);
     goto err;
   }
 
   MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_o_new(%p)", marpaWrapperValuep->marpaBocagep);
   marpaWrapperValuep->marpaOrderp = marpa_o_new(marpaWrapperValuep->marpaBocagep);
-  if (marpaWrapperValuep->marpaOrderp == NULL) {
+  if (MARPAWRAPPER_UNLIKELY(marpaWrapperValuep->marpaOrderp == NULL)) {
     MARPAWRAPPER_MARPA_G_ERROR(genericLoggerp, marpaWrapperRecognizerp->marpaWrapperGrammarp->marpaGrammarp);
     goto err;
   }
 
   highRankOnlyFlagi = (marpaWrapperValueOptionp->highRankOnlyb != 0) ? 1 : 0;
   MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_o_high_rank_only_set(%p, %d)", marpaWrapperValuep->marpaOrderp, highRankOnlyFlagi);
-  if (marpa_o_high_rank_only_set(marpaWrapperValuep->marpaOrderp, highRankOnlyFlagi) != highRankOnlyFlagi) {
+  if (MARPAWRAPPER_UNLIKELY(marpa_o_high_rank_only_set(marpaWrapperValuep->marpaOrderp, highRankOnlyFlagi) != highRankOnlyFlagi)) {
     MARPAWRAPPER_MARPA_G_ERROR(genericLoggerp, marpaWrapperRecognizerp->marpaWrapperGrammarp->marpaGrammarp);
     goto err;
   }
 
   if (marpaWrapperValueOptionp->orderByRankb != 0) {
     MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_o_rank(%p)", marpaWrapperValuep->marpaOrderp);
-    if (marpa_o_rank(marpaWrapperValuep->marpaOrderp) < 0) {
+    if (MARPAWRAPPER_UNLIKELY(marpa_o_rank(marpaWrapperValuep->marpaOrderp) < 0)) {
       MARPAWRAPPER_MARPA_G_ERROR(genericLoggerp, marpaWrapperRecognizerp->marpaWrapperGrammarp->marpaGrammarp);
       goto err;
     }
@@ -98,7 +103,7 @@ marpaWrapperValue_t *marpaWrapperValue_newp(marpaWrapperRecognizer_t *marpaWrapp
   if (marpaWrapperValueOptionp->ambiguousb == 0) {
     MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_o_ambiguity_metric(%p)", marpaWrapperValuep->marpaOrderp);
     ambiguousi = marpa_o_ambiguity_metric(marpaWrapperValuep->marpaOrderp);
-    if (ambiguousi < 0) {
+    if (MARPAWRAPPER_UNLIKELY(ambiguousi < 0)) {
       MARPAWRAPPER_MARPA_G_ERROR(genericLoggerp, marpaWrapperRecognizerp->marpaWrapperGrammarp->marpaGrammarp);
       goto err;
     } else if (ambiguousi > 1) {
@@ -110,7 +115,7 @@ marpaWrapperValue_t *marpaWrapperValue_newp(marpaWrapperRecognizer_t *marpaWrapp
   if (marpaWrapperValueOptionp->nullb == 0) {
     MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_o_is_null(%p)", marpaWrapperValuep->marpaOrderp);
     nulli = marpa_o_is_null(marpaWrapperValuep->marpaOrderp);
-    if (nulli < 0) {
+    if (MARPAWRAPPER_UNLIKELY(nulli < 0)) {
       MARPAWRAPPER_MARPA_G_ERROR(genericLoggerp, marpaWrapperRecognizerp->marpaWrapperGrammarp->marpaGrammarp);
       goto err;
     } else if (nulli >= 1) {
@@ -121,7 +126,7 @@ marpaWrapperValue_t *marpaWrapperValue_newp(marpaWrapperRecognizer_t *marpaWrapp
   
   MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_t_new(%p)", marpaWrapperValuep->marpaOrderp);
   marpaWrapperValuep->marpaTreep = marpa_t_new(marpaWrapperValuep->marpaOrderp);
-  if (marpaWrapperValuep->marpaTreep == NULL) {
+  if (MARPAWRAPPER_UNLIKELY(marpaWrapperValuep->marpaTreep == NULL)) {
     MARPAWRAPPER_MARPA_G_ERROR(genericLoggerp, marpaWrapperRecognizerp->marpaWrapperGrammarp->marpaGrammarp);
     goto err;
   }
@@ -130,7 +135,7 @@ marpaWrapperValue_t *marpaWrapperValue_newp(marpaWrapperRecognizer_t *marpaWrapp
     MARPAWRAPPER_TRACE(genericLoggerp, funcs, "Cloning genericLogger");
 
     marpaWrapperValuep->marpaWrapperValueOption.genericLoggerp = GENERICLOGGER_CLONE(genericLoggerp);
-    if (marpaWrapperValuep->marpaWrapperValueOption.genericLoggerp == NULL) {
+    if (MARPAWRAPPER_UNLIKELY(marpaWrapperValuep->marpaWrapperValueOption.genericLoggerp == NULL)) {
       MARPAWRAPPER_ERRORF(genericLoggerp, "Failed to clone genericLogger: %s", strerror(errno));
       goto err;
     }
@@ -176,7 +181,6 @@ short marpaWrapperValue_valueb(marpaWrapperValue_t               *marpaWrapperVa
 {
   /* We take much care to set marpaWrapperValuep->marpaValuep only around the callbacks */
   MARPAWRAPPER_FUNCS(marpaWrapperValue_valueb)
-  genericLogger_t  *genericLoggerp = NULL;
   int               tnexti;
   Marpa_Value       marpaValuep = NULL;
   int               nexti;
@@ -190,78 +194,78 @@ short marpaWrapperValue_valueb(marpaWrapperValue_t               *marpaWrapperVa
   int               nParsesi;
   short             callbackb;
 
-  if (marpaWrapperValuep == NULL) {
+#ifndef NDEBUG
+  if (MARPAWRAPPER_UNLIKELY(marpaWrapperValuep == NULL)) {
     errno = EINVAL;
     goto err;
   }
+#endif
 
-  genericLoggerp = marpaWrapperValuep->marpaWrapperValueOption.genericLoggerp;
-
-  MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_t_next(%p)", marpaWrapperValuep->marpaTreep);
+  MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_t_next(%p)", marpaWrapperValuep->marpaTreep);
   tnexti = marpa_t_next(marpaWrapperValuep->marpaTreep);
-  if (tnexti < -1) {
-    MARPAWRAPPER_MARPA_G_ERROR(genericLoggerp, marpaWrapperValuep->marpaWrapperRecognizerp->marpaWrapperGrammarp->marpaGrammarp);
+  if (MARPAWRAPPER_UNLIKELY(tnexti < -1)) {
+    MARPAWRAPPER_MARPA_G_ERROR(GENERICLOGGERP(marpaWrapperValuep), marpaWrapperValuep->marpaWrapperRecognizerp->marpaWrapperGrammarp->marpaGrammarp);
     goto err;
   } else if (tnexti == -1) {
-    MARPAWRAPPER_TRACE(genericLoggerp, funcs, "Tree iterator exhausted");
+    MARPAWRAPPER_TRACE(GENERICLOGGERP(marpaWrapperValuep), funcs, "Tree iterator exhausted");
     goto done;
   }
 
-  MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_t_parse_count(%p)", marpaWrapperValuep->marpaTreep);
+  MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_t_parse_count(%p)", marpaWrapperValuep->marpaTreep);
   nParsesi = marpa_t_parse_count(marpaWrapperValuep->marpaTreep);
   if ((marpaWrapperValuep->marpaWrapperValueOption.maxParsesi > 0) && (nParsesi > marpaWrapperValuep->marpaWrapperValueOption.maxParsesi)) {
-    MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "Maximum number of parse trees is reached: %d", marpaWrapperValuep->marpaWrapperValueOption.maxParsesi);
+    MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "Maximum number of parse trees is reached: %d", marpaWrapperValuep->marpaWrapperValueOption.maxParsesi);
     goto done;
   }
-  MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "Number of parse trees: %d, max=%d", nParsesi, marpaWrapperValuep->marpaWrapperValueOption.maxParsesi);
+  MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "Number of parse trees: %d, max=%d", nParsesi, marpaWrapperValuep->marpaWrapperValueOption.maxParsesi);
 
-  MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_new(%p)", marpaWrapperValuep->marpaTreep);
+  MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_new(%p)", marpaWrapperValuep->marpaTreep);
   marpaValuep = marpa_v_new(marpaWrapperValuep->marpaTreep);
-  if (marpaValuep == NULL) {
-    MARPAWRAPPER_MARPA_G_ERROR(genericLoggerp, marpaWrapperValuep->marpaWrapperRecognizerp->marpaWrapperGrammarp->marpaGrammarp);
+  if (MARPAWRAPPER_UNLIKELY(marpaValuep == NULL)) {
+    MARPAWRAPPER_MARPA_G_ERROR(GENERICLOGGERP(marpaWrapperValuep), marpaWrapperValuep->marpaWrapperRecognizerp->marpaWrapperGrammarp->marpaGrammarp);
     goto err;
   }
 
-  MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_valued_force(%p)", marpaValuep);
-  if (marpa_v_valued_force(marpaValuep) < 0) {
-    MARPAWRAPPER_MARPA_G_ERROR(genericLoggerp, marpaWrapperValuep->marpaWrapperRecognizerp->marpaWrapperGrammarp->marpaGrammarp);
+  MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_valued_force(%p)", marpaValuep);
+  if (MARPAWRAPPER_UNLIKELY(marpa_v_valued_force(marpaValuep) < 0)) {
+    MARPAWRAPPER_MARPA_G_ERROR(GENERICLOGGERP(marpaWrapperValuep), marpaWrapperValuep->marpaWrapperRecognizerp->marpaWrapperGrammarp->marpaGrammarp);
     goto err;
   }
 
   nexti = 1;
   while (nexti != 0) {
-    MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_step(%p)", marpaValuep);
+    MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_step(%p)", marpaValuep);
     stepi = marpa_v_step(marpaValuep);
-    if (stepi < 0) {
-      MARPAWRAPPER_MARPA_G_ERROR(genericLoggerp, marpaWrapperValuep->marpaWrapperRecognizerp->marpaWrapperGrammarp->marpaGrammarp);
+    if (MARPAWRAPPER_UNLIKELY(stepi < 0)) {
+      MARPAWRAPPER_MARPA_G_ERROR(GENERICLOGGERP(marpaWrapperValuep), marpaWrapperValuep->marpaWrapperRecognizerp->marpaWrapperGrammarp->marpaGrammarp);
       goto err;
     }
 
-    MARPAWRAPPER_MARPA_STEP_TRACE(genericLoggerp, funcs, stepi);
+    MARPAWRAPPER_MARPA_STEP_TRACE(GENERICLOGGERP(marpaWrapperValuep), funcs, stepi);
 
     switch (stepi) {
     case MARPA_STEP_RULE:
 
-      MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_rule(%p)", marpaValuep);
+      MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_rule(%p)", marpaValuep);
       marpaRuleIdi = marpa_v_rule(marpaValuep);
 
-      MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_arg_0(%p)", marpaValuep);
+      MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_arg_0(%p)", marpaValuep);
       argFirsti = marpa_v_arg_0(marpaValuep);
 
-      MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_arg_n(%p)", marpaValuep);
+      MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_arg_n(%p)", marpaValuep);
       argLasti = marpa_v_arg_n(marpaValuep);
 
-      MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_result(%p)", marpaValuep);
+      MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_result(%p)", marpaValuep);
       argResulti = marpa_v_result(marpaValuep);
 
-      MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "Rule %d: Stack [%d..%d] -> Stack %d", (int) marpaRuleIdi, argFirsti, argLasti, argResulti);
+      MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "Rule %d: Stack [%d..%d] -> Stack %d", (int) marpaRuleIdi, argFirsti, argLasti, argResulti);
 
       if (ruleCallbackp != NULL) {
         marpaWrapperValuep->marpaValuep = marpaValuep;
 	callbackb = ruleCallbackp(userDatavp, (int) marpaRuleIdi, argFirsti, argLasti, argResulti);
         marpaWrapperValuep->marpaValuep = NULL;
         if (callbackb == 0) {
-	  MARPAWRAPPER_ERRORF(genericLoggerp, "Rule No %d value callback failure", (int) marpaRuleIdi);
+	  MARPAWRAPPER_ERRORF(GENERICLOGGERP(marpaWrapperValuep), "Rule No %d value callback failure", (int) marpaRuleIdi);
 	  goto err;
 	}
       }
@@ -269,23 +273,23 @@ short marpaWrapperValue_valueb(marpaWrapperValue_t               *marpaWrapperVa
       break;
     case MARPA_STEP_TOKEN:
 
-      MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_token(%p)", marpaValuep);
+      MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_token(%p)", marpaValuep);
       marpaSymbolIdi = marpa_v_token(marpaValuep);
 
-      MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_token_value(%p)", marpaValuep);
+      MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_token_value(%p)", marpaValuep);
       tokenValuei = marpa_v_token_value(marpaValuep);
 
-      MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_result(%p)", marpaValuep);
+      MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_result(%p)", marpaValuep);
       argResulti = marpa_v_result(marpaValuep);
 
-      MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "Symbol %d: Stack %d -> Stack %d", (int) marpaSymbolIdi, tokenValuei, argResulti);
+      MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "Symbol %d: Stack %d -> Stack %d", (int) marpaSymbolIdi, tokenValuei, argResulti);
 
       if (symbolCallbackp != NULL) {
         marpaWrapperValuep->marpaValuep = marpaValuep;
 	callbackb = symbolCallbackp(userDatavp, (int) marpaSymbolIdi, tokenValuei, argResulti);
         marpaWrapperValuep->marpaValuep = NULL;
         if (callbackb == 0) {
-	  MARPAWRAPPER_ERRORF(genericLoggerp, "Symbol No %d value callback failure", (int) marpaSymbolIdi);
+	  MARPAWRAPPER_ERRORF(GENERICLOGGERP(marpaWrapperValuep), "Symbol No %d value callback failure", (int) marpaSymbolIdi);
 	  goto err;
 	}
       }
@@ -293,20 +297,20 @@ short marpaWrapperValue_valueb(marpaWrapperValue_t               *marpaWrapperVa
       break;
     case MARPA_STEP_NULLING_SYMBOL:
 
-      MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_symbol(%p)", marpaValuep);
+      MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_symbol(%p)", marpaValuep);
       marpaSymbolIdi = marpa_v_symbol(marpaValuep);
 
-      MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_result(%p)", marpaValuep);
+      MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_result(%p)", marpaValuep);
       argResulti = marpa_v_result(marpaValuep);
 
-      MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "Nulling symbol %d-> Stack %d", (int) marpaSymbolIdi, argResulti);
+      MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "Nulling symbol %d-> Stack %d", (int) marpaSymbolIdi, argResulti);
 
       if (nullingCallbackp != NULL) {
         marpaWrapperValuep->marpaValuep = marpaValuep;
 	callbackb = nullingCallbackp(userDatavp, (int) marpaSymbolIdi, argResulti);
         marpaWrapperValuep->marpaValuep = NULL;
         if (callbackb == 0) {
-	  MARPAWRAPPER_ERRORF(genericLoggerp, "Nulling symbol No %d value callback failure", (int) marpaSymbolIdi);
+	  MARPAWRAPPER_ERRORF(GENERICLOGGERP(marpaWrapperValuep), "Nulling symbol No %d value callback failure", (int) marpaSymbolIdi);
 	  goto err;
 	}
       }
@@ -322,29 +326,29 @@ short marpaWrapperValue_valueb(marpaWrapperValue_t               *marpaWrapperVa
     }
   }
   
-  MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_unref(%p)", marpaValuep);
+  MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_unref(%p)", marpaValuep);
   marpa_v_unref(marpaValuep);
 
-  MARPAWRAPPER_TRACE(genericLoggerp, funcs, "return 1");
+  MARPAWRAPPER_TRACE(GENERICLOGGERP(marpaWrapperValuep), funcs, "return 1");
   return 1;
   
  done:
   if (marpaValuep != NULL) {
-    MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_unref(%p)", marpaValuep);
+    MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_unref(%p)", marpaValuep);
     marpa_v_unref(marpaValuep);
   }
 
-  MARPAWRAPPER_TRACE(genericLoggerp, funcs, "return 0");
+  MARPAWRAPPER_TRACE(GENERICLOGGERP(marpaWrapperValuep), funcs, "return 0");
   return 0;
   
  err:
   if (marpaValuep != NULL) {
     int errnoi = errno;
-    MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_unref(%p)", marpaValuep);
+    MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_unref(%p)", marpaValuep);
     marpa_v_unref(marpaValuep);
     errno = errnoi;
   }
-  MARPAWRAPPER_TRACE(genericLoggerp, funcs, "return -1");
+  MARPAWRAPPER_TRACE(GENERICLOGGERP(marpaWrapperValuep), funcs, "return -1");
   return -1;
 }
 
@@ -353,47 +357,45 @@ short marpaWrapperValue_value_startb(marpaWrapperValue_t *marpaWrapperValuep, in
 /****************************************************************************/
 {
   MARPAWRAPPER_FUNCS(marpaWrapperValue_value_startb)
-  genericLogger_t    *genericLoggerp = NULL;
   Marpa_Step_Type     step_type;
   Marpa_Earley_Set_ID start_earley_set;
 
-  if (marpaWrapperValuep == NULL) {
+#ifndef NDEBUG
+  if (MARPAWRAPPER_UNLIKELY(marpaWrapperValuep == NULL)) {
     errno = EINVAL;
     goto err;
   }
+#endif
 
-  genericLoggerp = marpaWrapperValuep->marpaWrapperValueOption.genericLoggerp;
-
-  if (marpaWrapperValuep->marpaValuep == NULL) {
-    MARPAWRAPPER_ERROR(genericLoggerp, "marpaWrapperValue_value_startb() called outside of marpaWrapperValue_valueb()");
+  if (MARPAWRAPPER_UNLIKELY(marpaWrapperValuep->marpaValuep == NULL)) {
+    MARPAWRAPPER_ERROR(GENERICLOGGERP(marpaWrapperValuep), "marpaWrapperValue_value_startb() called outside of marpaWrapperValue_valueb()");
     goto err;
   }
 
-  genericLoggerp = marpaWrapperValuep->marpaWrapperValueOption.genericLoggerp;
   step_type = marpa_v_step_type(marpaWrapperValuep->marpaValuep);
   switch (step_type) {
   case MARPA_STEP_RULE:
-    MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_rule_start_es_id(%p)", marpaWrapperValuep->marpaValuep);
+    MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_rule_start_es_id(%p)", marpaWrapperValuep->marpaValuep);
     start_earley_set = marpa_v_rule_start_es_id(marpaWrapperValuep->marpaValuep);
     break;
   case MARPA_STEP_TOKEN:
   case MARPA_STEP_NULLING_SYMBOL:
-    MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_token_start_es_id(%p)", marpaWrapperValuep->marpaValuep);
+    MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_token_start_es_id(%p)", marpaWrapperValuep->marpaValuep);
     start_earley_set = marpa_v_token_start_es_id(marpaWrapperValuep->marpaValuep);
     break;
   default:
-    MARPAWRAPPER_WARNF(genericLoggerp, "Unsupported step type %d", (int) step_type);
+    MARPAWRAPPER_WARNF(GENERICLOGGERP(marpaWrapperValuep), "Unsupported step type %d", (int) step_type);
     goto err;
   }
 
   if (startip != NULL) {
     *startip = (int) start_earley_set;
   }
-  MARPAWRAPPER_TRACE(genericLoggerp, funcs, "return 1");
+  MARPAWRAPPER_TRACE(GENERICLOGGERP(marpaWrapperValuep), funcs, "return 1");
   return 1;
 
  err:
-  MARPAWRAPPER_TRACE(genericLoggerp, funcs, "return 0");
+  MARPAWRAPPER_TRACE(GENERICLOGGERP(marpaWrapperValuep), funcs, "return 0");
   return 0;
 }
 
@@ -402,31 +404,29 @@ short marpaWrapperValue_value_lengthb(marpaWrapperValue_t *marpaWrapperValuep, i
 /****************************************************************************/
 {
   MARPAWRAPPER_FUNCS(marpaWrapperValue_value_lengthb)
-  genericLogger_t    *genericLoggerp = NULL;
   Marpa_Step_Type     step_type;
   Marpa_Earley_Set_ID start_earley_set;
   Marpa_Earley_Set_ID end_earley_set;
   int                 lengthi;
 
-  if (marpaWrapperValuep == NULL) {
+#ifndef NDEBUG
+  if (MARPAWRAPPER_UNLIKELY(marpaWrapperValuep == NULL)) {
     errno = EINVAL;
     goto err;
   }
+#endif
 
-  genericLoggerp = marpaWrapperValuep->marpaWrapperValueOption.genericLoggerp;
-
-  if (marpaWrapperValuep->marpaValuep == NULL) {
-    MARPAWRAPPER_ERROR(genericLoggerp, "marpaWrapperValue_value_lengthb() called outside of marpaWrapperValue_valueb()");
+  if (MARPAWRAPPER_UNLIKELY(marpaWrapperValuep->marpaValuep == NULL)) {
+    MARPAWRAPPER_ERROR(GENERICLOGGERP(marpaWrapperValuep), "marpaWrapperValue_value_lengthb() called outside of marpaWrapperValue_valueb()");
     goto err;
   }
 
-  genericLoggerp = marpaWrapperValuep->marpaWrapperValueOption.genericLoggerp;
   step_type = marpa_v_step_type(marpaWrapperValuep->marpaValuep);
   switch (step_type) {
   case MARPA_STEP_RULE:
-    MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_rule_start_es_id(%p)", marpaWrapperValuep->marpaValuep);
+    MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_rule_start_es_id(%p)", marpaWrapperValuep->marpaValuep);
     start_earley_set = marpa_v_rule_start_es_id(marpaWrapperValuep->marpaValuep);
-    MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_es_id(%p)", marpaWrapperValuep->marpaValuep);
+    MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_es_id(%p)", marpaWrapperValuep->marpaValuep);
     end_earley_set = marpa_v_es_id(marpaWrapperValuep->marpaValuep);
     lengthi = end_earley_set - start_earley_set + 1;
     break;
@@ -434,25 +434,25 @@ short marpaWrapperValue_value_lengthb(marpaWrapperValue_t *marpaWrapperValuep, i
     lengthi = 0;
     break;
   case MARPA_STEP_TOKEN:
-    MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_token_start_es_id(%p)", marpaWrapperValuep->marpaValuep);
+    MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_token_start_es_id(%p)", marpaWrapperValuep->marpaValuep);
     start_earley_set = marpa_v_token_start_es_id(marpaWrapperValuep->marpaValuep);
-    MARPAWRAPPER_TRACEF(genericLoggerp, funcs, "marpa_v_es_id(%p)", marpaWrapperValuep->marpaValuep);
+    MARPAWRAPPER_TRACEF(GENERICLOGGERP(marpaWrapperValuep), funcs, "marpa_v_es_id(%p)", marpaWrapperValuep->marpaValuep);
     end_earley_set = marpa_v_es_id(marpaWrapperValuep->marpaValuep);
     lengthi = end_earley_set - start_earley_set + 1;
     break;
   default:
-    MARPAWRAPPER_WARNF(genericLoggerp, "Unsupported step type %d", (int) step_type);
+    MARPAWRAPPER_WARNF(GENERICLOGGERP(marpaWrapperValuep), "Unsupported step type %d", (int) step_type);
     goto err;
   }
 
   if (lengthip != NULL) {
     *lengthip = lengthi;
   }
-  MARPAWRAPPER_TRACE(genericLoggerp, funcs, "return 1");
+  MARPAWRAPPER_TRACE(GENERICLOGGERP(marpaWrapperValuep), funcs, "return 1");
   return 1;
 
  err:
-  MARPAWRAPPER_TRACE(genericLoggerp, funcs, "return 0");
+  MARPAWRAPPER_TRACE(GENERICLOGGERP(marpaWrapperValuep), funcs, "return 0");
   return 0;
 }
 
